To add tracing to your Langflow application, add Arize environment variables to your Langflow application. Arize begins monitoring and collecting telemetry data from your LLM applications automatically.

# Arize Env Variables
```bash
export ARIZE_SPACE_ID="YOUR_ARIZE_SPACE_ID"
export ARIZE_API_KEY="YOUR_ARIZE_API_KEY"
```
